@@ -7,8 +7,10 @@ import webbrowser
 from functools import lru_cache
 from typing import Awaitable, Callable
 
-from loguru import logger
+import pkg_resources
+import httpx
 
+from loguru import logger
 
 @logger.catch
 def open_url(url: str):
@@ -47,6 +49,26 @@ def retrieve_installed_version() -> str:
     )
     return bytes_version.decode()
 
+@logger.catch
+def check_and_upgrade():
+    logger.info("Checking for updates")
+
+    version = pkg_resources.get_distribution("db0mb3r").version
+    updates = httpx.get("https://raw.githubusercontent.com/dmitrijkotov634/b0mb3r/master/version")
+
+    if updates.status_code == 200:
+        values = updates.text[1:].split("\r\n", maxsplit=1)
+
+        if version == values[0]:
+            logger.success("No update required")
+        else:
+            logger.info("Downloading an update using pip")
+
+            subprocess.check_call([sys.executable, "-m", "pip", "install", "db0mb3r==" + values[0]])
+            logger.success("db0mb3r updated, changes will take effect after restart")
+
+            print("\nChanges {}:\n{}\n".format(*values))          
+            os.chdir(os.path.join(pkg_resources.get_distribution("db0mb3r").location, "db0mb3r"))
 
 @logger.catch
 async def await_with_callback(
